
/******************************************************************************
  TimeoutServer c'tor

 ******************************************************************************/
function TimeoutServer( )
{
    this.m_pendingTimeouts  = { };
    this.m_nextTimeoutId    = 0;
    this.m_shutdown         = false;
}
TimeoutServer.prototype =
{
    Shutdown : function( )
    {
        this.m_shutdown = true;

        for ( var timeoutId in this.m_pendingTimeouts )
        {
            var timeout = this.m_pendingTimeouts[ timeoutId ];

            clearTimeout( timeout );
        }

        this.m_pendingTimeouts = null;
    },

    CancelTimeout : function( timeoutId )
    {
        try
        {
            if ( this.m_pendingTimeouts[ timeoutId ] !== undefined )
            {
                clearTimeout( this.m_pendingTimeouts[ timeoutId ] );
                delete this.m_pendingTimeouts[ timeoutId ];
            }
        }
        catch ( e )
        {
            EX_ASSERT_NO_EXCEPTIONS( e, "TimeoutServer::CancelTimeout( )" );
        }
    },

    RequestTimeout : function( operation, delayMS )
    {
        try
        {
            if ( this.m_shutdown )
            {
                throw new TS_EX_TimeoutServerShutdown( );
            }

            var timeoutId = this.m_nextTimeoutId++;

            var self = this;
            function HandleTimeout( )
            {
                try
                {
                    if ( self.m_shutdown )
                    {
                        return;
                    }

                    self.CancelTimeout( timeoutId );

                    operation( );
                }
                catch ( e )
                {
                    EX_Log( "TimeoutServer::RequestTimeout( ).HandleTimeout( ) : " + e.message );
                }
            }

            if ( this.m_pendingTimeouts[ timeoutId ] !== undefined )
            {
                throw new EX_ProgrammingError( "Timeout id " + timeoutId + " already exists in pending timeouts." );
            }

            this.m_pendingTimeouts[ timeoutId ] = setTimeout( HandleTimeout, delayMS );

            return timeoutId;
        }
        catch ( e )
        {
            if ( e instanceof TS_EX_TimeoutServerShutdown )
            {
                throw e;
            }

            EX_ASSERT_NO_EXCEPTIONS( e, "TimeoutServer::RequestTimeout( )" );
        }
    }
};